Credits
-------

Authors
~~~~~~~

HydrOffice BAG is written and maintained by:

- `Giuseppe Masetti <mailto:gmasetti@ccom.unh.edu>`_

Contributors
~~~~~~~~~~~~

The following wonderful people contributed directly or indirectly to this project:

- `Matt Wilson <mailto:matt.wilson@noaa.gov>`_

- `Brian Calder <mailto:brc@ccom.unh.edu>`_

Please add yourself here alphabetically when you submit your first pull request.
